==> zymbit-connect-0.1.1.tar.gz: zymbit-connect-0.1.1/zymbit/util/time.py <==


import datetime
import logging
import pytz

# it's impossible that "now" is less than this datetime
# we know we are out of sync with real time if we ever
# get a time value less than this
MIN_DT = datetime.datetime(2014, 7, 25, 17, 00, 00)  # Zymbit est date, UTC

LONG_TIME_AGO = datetime.datetime(1, 1, 1)  # a really long time ago

utc = pytz.utc


def now():
    return utc.localize(datetime.datetime.utcnow())


def timestamp(dt=None):
    if dt is None:
        dt = now()

    return dt.isoformat('T')


def get_sleep_time(seconds, start):
    """
    Wait at most the given number of seconds from the initial time given
    :param seconds: float - number of seconds to wait
    :param start: datetime - the start time
    :return: float - time to wait
    """
    _now = now()
    delta = _now - start
    diff = delta.seconds + (1.0 * delta.microseconds / 1e6)
    wait = max(0, seconds - diff)

    # print 'start={}, _now={}, delta={}, diff={}, wait={}'.format(start, _now, delta, diff, wait)

    return wait


class MillisDatetime(object):
    def __init__(self, millis):
        self.last_millis = None
        self.initial = None

        self.set_initial(millis)

    @property
    def logger(self):
        return logging.getLogger(__name__)

    def get_time(self, millis):
        if millis < self.last_millis:
            self.logger.info(
                'time rolled over, last_millis={}, millis={}'.format(
                    self.last_millis, millis))

            self.set_initial(millis)

        delta = datetime.timedelta(milliseconds=millis)
        return self.initial + delta

    def set_initial(self, millis):
        delta = datetime.timedelta(milliseconds=millis)
        self.initial = now() - delta

        self.last_millis = millis

==> zymbit-connect-0.2.0.tar.gz: zymbit-connect-0.2.0/zymbit/util/time.py <==


import datetime
import functools
import logging
import pytz

# it's impossible that "now" is less than this datetime
# we know we are out of sync with real time if we ever
# get a time value less than this
MIN_DT = datetime.datetime(2014, 7, 25, 17, 00, 00)  # Zymbit est date, UTC

utc = pytz.utc

LONG_TIME_AGO = utc.localize(datetime.datetime(1, 1, 1))  # a really long time ago


def now():
    return utc.localize(datetime.datetime.utcnow())


def timestamp(dt=None):
    if dt is None:
        dt = now()

    return dt.isoformat('T')


def get_sleep_time(seconds, start):
    """
    Wait at most the given number of seconds from the initial time given
    :param seconds: float - number of seconds to wait
    :param start: datetime - the start time
    :return: float - time to wait
    """
    _now = now()
    delta = _now - start
    diff = delta.seconds + (1.0 * delta.microseconds / 1e6)
    wait = max(0, seconds - diff)

    # print 'start={}, _now={}, delta={}, diff={}, wait={}'.format(start, _now, delta, diff, wait)

    return wait


def interval(interval_delay, default_return=None):
    """
    Call a function every given interval
    :param interval_delay: float - number of seconds
    :param default_return: when the interval has not passed, what to return (default: None)
    """
    interval_delta = datetime.timedelta(seconds=interval_delay)

    def wrapper(fn):
        @functools.wraps(fn)
        def interval_handler(*args, **kwargs):
            t0 = now()
            last_call = getattr(fn, 'last_call', LONG_TIME_AGO)

            if (t0 - last_call) > interval_delta:
                fn.last_call = t0

                print('calling fn={}'.format(fn))
                return fn(*args, **kwargs)
            else:
                print('not at interval_delta={}'.format(interval_delta))
                return default_return

        return interval_handler

    return wrapper


class MillisDatetime(object):
    def __init__(self, millis):
        self.last_millis = None
        self.initial = None

        self.set_initial(millis)

    @property
    def logger(self):
        return logging.getLogger(__name__)

    def get_time(self, millis):
        if millis < self.last_millis:
            self.logger.info(
                'time rolled over, last_millis={}, millis={}'.format(
                    self.last_millis, millis))

            self.set_initial(millis)

        delta = datetime.timedelta(milliseconds=millis)
        return self.initial + delta

    def set_initial(self, millis):
        delta = datetime.timedelta(milliseconds=millis)
        self.initial = now() - delta

        self.last_millis = millis
